@@ -6,15 +6,19 @@
  * This example is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRENTY; without event the implied warrenty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
  */
 
 #include <mikmod.h>
-#if !defined(_WIN32)
+
+#if defined(_WIN32)
+#define MikMod_Sleep(ns) Sleep(ns / 1000)
+#elif defined(_MIKMOD_AMIGA)
+void amiga_sysinit (void);
+void amiga_usleep (unsigned long timeout);
+#define MikMod_Sleep(ns) amiga_usleep(ns)
+#else
 #include <unistd.h>  /* for usleep() */
 #define MikMod_Sleep(ns) usleep(ns)
-#else
-#define MikMod_Sleep(ns) Sleep(ns / 1000)
 #endif
 
 int main(int argc, char **argv)
@@ -26,6 +30,10 @@ int main(int argc, char **argv)
 		return 1;
 	}
 
+#ifdef _MIKMOD_AMIGA
+	amiga_sysinit ();
+#endif
+
 	/* initialize MikMod threads */
 	MikMod_InitThreads ();
 
@@ -47,7 +55,7 @@ int main(int argc, char **argv)
 	module = Player_Load(argv[1], 64, 0);
 	if (module) {
 		/* start module */
-		printf("Playing %s (%d chn)\n", module->songname, module->numchn);
+		printf("Playing %s (%d chn)\n", module->songname, (int) module->numchn);
 		Player_Start(module);
 
 		while (Player_Active()) {
